@@ -1,5 +1,10 @@
 from enum import Enum, unique
 
+__all__ = ('RequestMethod', 'ChatType', 'ChatAction', 'ChatMemberStatus',
+           'MessageEntityType', 'UpdateType', 'ContentType', 'ParseMode',
+           'PollType', 'DiceEmoji', 'InputMediaType', 'InlineQueryResultType',
+           'PassportElementType')
+
 
 @unique
 class RequestMethod(str, Enum):
@@ -21,8 +26,8 @@ class ChatAction(str, Enum):
     UPLOAD_PHOTO = 'upload_photo'
     RECORD_VIDEO = 'record_video'
     UPLOAD_VIDEO = 'upload_video'
-    RECORD_AUDIO = 'record_audio'
-    UPLOAD_AUDIO = 'upload_audio'
+    RECORD_VOICE = 'record_voice'
+    UPLOAD_VOICE = 'upload_voice'
     UPLOAD_DOCUMENT = 'upload_document'
     FIND_LOCATION = 'find_location'
     RECORD_VIDEO_NOTE = 'record_video_note'
@@ -69,6 +74,10 @@ class UpdateType(str, Enum):
     CALLBACK_QUERY = 'callback_query'
     SHIPPING_QUERY = 'shipping_query'
     PRE_CHECKOUT_QUERY = 'pre_checkout_query'
+    POLL = 'poll'
+    POLL_ANSWER = 'poll_answer'
+    MY_CHAT_MEMBER = 'my_chat_member'
+    CHAT_MEMBER = 'chat_member'
 
 
 @unique
@@ -121,6 +130,7 @@ class DiceEmoji(str, Enum):
     BASKETBALL = '🏀'
     FOOTBALL = '⚽'
     SLOT_MACHINE = '🎰'
+    BOWLING = '🎳'
 
 
 @unique
